@@ -26,11 +26,17 @@ main(int argc, char **argv)
   lou_indexTables(tables);
   match = lou_findTable("id:foo");
   success |= (!match || (strstr(match, "tablesWithMetadata/foo") == NULL));
+  free(match);
   match = lou_findTable("language:en");
   success |= (!match || (strstr(match, "tablesWithMetadata/bar") == NULL));
+  free(match);
   matches = lou_findTables("language:en");
   success |= (!matches || !matches[0] || (strstr(matches[0], "tablesWithMetadata/bar") == NULL));
   success |= (!matches || !matches[0] || !matches[1] || (strstr(matches[1], "tablesWithMetadata/foo") == NULL));
+  if (matches) {
+    for (int i = 0; matches[i]; i++) free(matches[i]);
+    free(matches);
+  }
   lou_free();
   return success;
 }
